from . import common
from . import errors


# =====
class DowntimesApi(common.BaseApi):
    def get(self, host, service=None, handle="api/downtime/check.sbml"):
        attrs = {
            "object":         host,
            "append_comment": "1",
            "downtime_type":  "current_future",
        }
        if service is not None:
            attrs["eventtype"] = service

        result = self._get(handle, attrs)
        if result.status_code == 200 and result.text.startswith("ok"):
            values = result.text.split(" ", 3)[1:]
            if len(values) == 0:
                return None  # No downtime
            elif len(values) == 3:
                return {
                    "start":       int(values[0]),
                    "end":         int(values[1]),
                    "description": values[2].strip(),
                }
            else:
                raise RuntimeError("Invalid response from Golem: {}".format(values))
        else:
            raise errors.GolemApiError(result)

    def set(self, host, user, timeout, description, service=None, handle="api/downtime/set.sbml"):
        attrs = {
            "hostname":     host,
            "user":         user,
            "downtime_for": timeout,
            "comment":      description,
        }
        if service is not None:
            attrs["service"] = service
            attrs["cmd"] = "service_downtime"
        else:
            attrs["cmd"] = "host_downtime"

        result = self._post(handle, attrs)
        if result.status_code == 200 and result.text.startswith("ok"):
            return
        else:
            raise errors.GolemApiError(result)

    def delete(self, host, user, description, service=None, handle="api/downtime/set.sbml"):
        self.set(host, user, 1, description, service, handle)
