import hashlib
import json

from ulib import typetools

from . import common
from . import errors


# =====
OK = "OK"
INFO = "INFO"  # XXX: Don't use this status! This is only for compatibility with Juggler.
WARN = "WARN"
CRIT = "CRIT"


# =====
def normalize_description(status, description):
    if not isinstance(description, dict):
        return {
            "status":      status,
            "description": description,
        }
    elif "status" not in description:
        description = dict(description)
        description["status"] = status
    return description


def make_description_hash(description):
    return typetools.object_hash(
        description,
        hasher=lambda text: hashlib.md5(text.encode()).hexdigest(),
    )


# =====
class EventsApi(common.BaseApi):
    def send(self, host, service, status, description, monitor=None, handle="api/events/submit.sbml"):
        description = normalize_description(status, description)

        attrs = {
            "object":    host,
            "eventtype": service,
            "status": {
                OK:   "ok",
                INFO: "ok",
                WARN: "warning",
                CRIT: "critical",
            }[status],
            "json":      "true",
            "md":        make_description_hash(description),
            "info":      json.dumps(description),
        }
        if monitor is not None:
            attrs["monitor"] = monitor

        result = self._post(handle, attrs)

        if result.status_code == 200 and result.text.startswith("ok"):
            return
        elif result.text.startswith("error: no current event"):
            raise errors.GolemNoCurrentEventError(result)
        else:
            raise errors.GolemApiError(result)
